# django-power-extensions

Collections of django extensions.

## Collections

**Note:**

1. django-click 2.1.0 requires click 6.x.

### python libraries

- ipython>=7.13.0
- mysqlclient>=1.4.6
- bizerror>=0.2.3
- fastutils>=0.9.0
- requests>=2.23.0
- PyYAML>=5.3
- redis>=3.4.1
- pillow>=7.0.0
- croniter>=0.3.31
- click~=6.7

### django

- django~=2.2.0
- django-click==2.1.0
- django-apiview>=0.2.0 
- django-redis-cache>=2.1.0
- django-simple-tags>=0.4.0

### django hacks

- django-checkbox-normalize>=0.1.0
- django-fullname-localization>=0.1.0

### static libraries

- django-static-jquery3>=3.3.1.1
- django-static-jquery-ui>=1.12.1.1
- django-static-fontawesome>=5.12.1.4
- django-static-ionicons>=2.0.1.2
- django-static-bootstrap>=3.3.7.1
- django-static-respond>=1.4.2.2
- django-static-html5shiv>=3.7.3.2
- django-static-echarts>=4.0.4.1
- django-static-adminlte>=2.4.3.2

### django widgets

- django-simple-captcha>=0.5.12
- django-yearmonth-widget>=0.2.1
- django-secure-password-input>=0.1.0
- django-toggle-switch-widget>=0.1.0
- django-cascading-dropdown-widget>=0.2.0
- django-lookup-table-rating-widget>=0.1.0
- django-gazing-select-widget>=0.1.1
- django-ckeditor>=5.9.0

### django middlewares

- django-middleware-global-request>=0.2.0

### django model extentions

- django-mptt>=0.11.0
- django-dataperm-model>=0.1.0
- django-admin-item-owner>=0.2.0

### django admin extensions

- django-import-export>=2.0.2
- django-modeladmin-reorder>=0.3.1
- django-msms-admin>=0.2.0
- django-readedit-switch-admin>=0.4.2
- django-changelist-toolbar-admin>=0.2.0
- django-cards-admin>=0.3.0
- django-admin-fix-ie-compatible>=0.1.1
- django-admin-safe-login>=0.2.0
- django-force-disable-permissions-admin>=0.2.0
- django-with-extra-context-admin>=0.1.0
- django-dynamic-resource-admin>=0.1.0
- django-visit-on-site-in-new-window>=0.1.0
- django-tabbed-changeform-admin>=0.1.3
- django-admin-app-sidebar>=0.1.0

### Simple system

- django-redis-counter>=0.1.1

### Complex system

- django-power-cms>=0.3.2
- django-simple-workflow>=0.1.0
- django-dynamic-model-admin>=0.2.1

## Releases

### v0.5.0 2020/03/31

1. Add django-gazing-select-widget.
1. Upgrade django-msms-admin to 0.2.0.
1. Upgrade django-cascading-dropdown-widget to 0.2.0.
1. Upgrade django-yearmonth-widget to 0.2.1.
1. Upgrade django-dynamic-model-admin to 0.2.1.
1. Upgrade django-power-cms to 0.3.2.

### v0.4.0 2020/03/22

1. Add django-admin-app-sidebar.
1. Upgrade django-cards-admin to 0.3.0.
1. Upgrade django-simple-tags to 0.4.0.
1. Upgrade django-tabbed-changeform-admin to 0.1.3.
1. Upgrade django-power-cms to 0.3.1.
1. Upgrade django-msms-admin to 0.1.2.
1. Upgrade django-admin-fix-ie-compatible to 0.1.1.

### v0.3.0 2020/03/19

1. Fix django-click and click incompatible problem.
1. Upgrade django-static-jquery-ui to 1.12.1.1.
1. Upgrade django-static-respond to 1.4.2.2.
1. Upgrade django-yearmonth-widget to 0.2.0.
1. Add admin extension django-visit-on-site-in-new-window.
1. Add admin extension django-tabbed-changeform-admin.
1. Add admin extension django-lookup-table-rating-widget.

### v0.2.0 2020/03/17

1. Add django-dynamic-model-admin.
1. Add django-simple-workflow.

### v0.1.0 2020/03/16

1. First release.